import "Turbine";
import "Turbine.Debug";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "DhorPlugins.Extensions";
import "DhorPlugins.Utils.BitOps";

LogWindow = class(Turbine.UI.Lotro.Window);

function LogWindow:Constructor(parent, data)
	Turbine.UI.Lotro.Window.Constructor( self );
	
   -- set size of window	
	self.width = 710;
	self.height = 300;
	self.windowWidth, self.windowHeight = Turbine.UI.Display:GetSize();
	
	-- some graph base settings
	self.gLocX = 80;
	self.gLocY = 40;
	self.gWidth = 600;
	self.gHeight = 198;
	
	-- create link to parent window
	self.mainWindow = parent;
   
	-- set the default window settings
	self:SetPosition(self.windowWidth /2 - self.width/2,self.windowHeight/2 - self.height/2);	
	self:SetSize( self.width, self.height );
	self:SetBlendMode(Turbine.UI.BlendMode.Undefined);
	self:SetBackColor( Turbine.UI.Color(0.0,0,0,0) );
	self:SetText( logWindowTitleString );
	self:SetOpacity( 1 );
   self:SetVisible(true);
   
   -- setup the X labels
   self.dataLabels = { };   
   
   self:AddLabels(data);
   self:AddGraph(data);
   
   	-- have the main window close the options
   self.VisibleChanged = function(sender,args)
      if(self:IsVisible() == false) then
         if(parent ~= nil) then
            parent:CloseLog();
         end
      end
   end	
end

function LogWindow:AddLabels(data)

   if(table.getn(data) == 0) then
      return;
   end

   fullTime = data[table.getn(data)][1];


   -- focus label option
   self.focusLabel = Turbine.UI.Label();
   self.focusLabel:SetSize(70,20);
   self.focusLabel:SetPosition(20,130);
   self.focusLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.focusLabel:SetParent(self);
   self.focusLabel:SetText(focusString);
   self.focusLabel:SetVisible(true);   
   
   -- time label option
   self.timeLabel = Turbine.UI.Label();
   self.timeLabel:SetSize(270,20);
   self.timeLabel:SetPosition(215,270);
   self.timeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.timeLabel:SetParent(self);
   self.timeLabel:SetText(timeString);
   self.timeLabel:SetVisible(true);
   
   -- zero focus label option
   self.zfocusLabel = Turbine.UI.Label();
   self.zfocusLabel:SetSize(10,20);
   self.zfocusLabel:SetPosition(self.gLocX - 10,self.gLocY + 188);
   self.zfocusLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.zfocusLabel:SetParent(self);
   self.zfocusLabel:SetText("0");
   self.zfocusLabel:SetVisible(true);
   
   -- three focus label option
   self.tfocusLabel = Turbine.UI.Label();
   self.tfocusLabel:SetSize(10,20);
   self.tfocusLabel:SetPosition(self.gLocX - 10,self.gLocY + 122);
   self.tfocusLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.tfocusLabel:SetParent(self);
   self.tfocusLabel:SetText("3");
   self.tfocusLabel:SetVisible(true);
   
   -- six focus label option
   self.sfocusLabel = Turbine.UI.Label();
   self.sfocusLabel:SetSize(10,20);
   self.sfocusLabel:SetPosition(self.gLocX - 10,self.gLocY + 56);
   self.sfocusLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.sfocusLabel:SetParent(self);
   self.sfocusLabel:SetText("6");
   self.sfocusLabel:SetVisible(true);
   
   -- nine focus label option
   self.nfocusLabel = Turbine.UI.Label();
   self.nfocusLabel:SetSize(10,20);
   self.nfocusLabel:SetPosition(self.gLocX - 10,self.gLocY - 10);
   self.nfocusLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.nfocusLabel:SetParent(self);
   self.nfocusLabel:SetText("9");
   self.nfocusLabel:SetVisible(true);   
    
   -- zero time label option
   self.ztimeLabel = Turbine.UI.Label();
   self.ztimeLabel:SetSize(10,20);
   self.ztimeLabel:SetPosition(self.gLocX - 5,self.gLocY + self.gHeight);
   self.ztimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.ztimeLabel:SetParent(self);
   self.ztimeLabel:SetText("0");
   self.ztimeLabel:SetVisible(true);   
    
   -- 25% time label option
   self.atimeLabel = Turbine.UI.Label();
   self.atimeLabel:SetSize(50,20);
   self.atimeLabel:SetPosition(self.gLocX + self.gWidth * 1 / 4 - 25,self.gLocY + self.gHeight);
   self.atimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.atimeLabel:SetParent(self);
   self.atimeLabel:SetText(string.format("%.2f",fullTime * 1 / 4));
   self.atimeLabel:SetVisible(true);  
    
   -- 50% time label option
   self.btimeLabel = Turbine.UI.Label();
   self.btimeLabel:SetSize(50,20);
   self.btimeLabel:SetPosition(self.gLocX + self.gWidth * 2 / 4 - 25,self.gLocY + self.gHeight);
   self.btimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.btimeLabel:SetParent(self);
   self.btimeLabel:SetText(string.format("%.2f",fullTime * 2 / 4));
   self.btimeLabel:SetVisible(true);   
    
   -- 75% time label option
   self.ctimeLabel = Turbine.UI.Label();
   self.ctimeLabel:SetSize(50,20);
   self.ctimeLabel:SetPosition(self.gLocX + self.gWidth * 3 / 4 - 25,self.gLocY + self.gHeight);
   self.ctimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.ctimeLabel:SetParent(self);
   self.ctimeLabel:SetText(string.format("%.2f",fullTime * 3 / 4));
   self.ctimeLabel:SetVisible(true);  
    
   -- 100% time label option
   self.dtimeLabel = Turbine.UI.Label();
   self.dtimeLabel:SetSize(50,20);
   self.dtimeLabel:SetPosition(self.gLocX + self.gWidth * 4 / 4 - 25,self.gLocY + self.gHeight);
   self.dtimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.dtimeLabel:SetParent(self);
   self.dtimeLabel:SetText(string.format("%.2f",fullTime));
   self.dtimeLabel:SetVisible(true);
   
   -- add the labels for each data point
   for i,v in ipairs(data) do
   
      -- get the x location
      x = self.gLocX + self.gWidth - (((fullTime - v[1])/fullTime) * self.gWidth) - 5;
      
      -- get the y location
      y = self.gLocY + ((self.gHeight / 9) * (9 - v[2])) - 10;
         
      self.dataLabels[i] = Turbine.UI.Label();
      self.dataLabels[i]:SetSize(10,20);
      self.dataLabels[i]:SetPosition(x,y);
      self.dataLabels[i]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
      self.dataLabels[i]:SetParent(self);
      self.dataLabels[i]:SetZOrder(50);
      self.dataLabels[i]:SetText("X");
      self.dataLabels[i]:SetVisible(true);   
   end
end

function LogWindow:AddGraph(data)

   self.graphBox = Turbine.UI.Lotro.TextBox();
   self.graphBox:SetSize(self.gWidth,self.gHeight);
   self.graphBox:SetPosition(self.gLocX,self.gLocY);
   self.graphBox:SetZOrder(0);
   self.graphBox:SetParent(self);
   self.graphBox:SetReadOnly(true);
   self.graphBox:SetVisible(true);   
end